@@ -25,10 +25,12 @@ volcano_plot <- function(mets, cutoff = NULL) {
   #' @return plot of results
   #'  
   #' @examples 
-  #' data("sample_data")
-  #' 
-  #' amanida_result <- compute_amanida(sample_data)
-  #' volcano_plot(amanida_result)
+  #' \dontrun{
+  #'    data("sample_data")
+  #'    
+  #'    amanida_result <- compute_amanida(sample_data)
+  #'    volcano_plot(amanida_result)
+  #' }
   #'
   #' @export
   #' 
@@ -113,7 +115,7 @@ volcano_plot <- function(mets, cutoff = NULL) {
     # Axis titles
     xlab( "log2(Fold-change)") + 
     ylab(expression(paste("-log10(", italic(p), "-value)"))) + 
-    labs(colour = "") +
+    labs(colour = "", tag = "Created with amanida") +
     
     # X axis breaks
     scale_x_continuous(breaks = seq(round(-max(abs(.$lfc)),0) - 1, 
@@ -128,7 +130,9 @@ volcano_plot <- function(mets, cutoff = NULL) {
                colour = "black", 
                linetype = "dashed") + 
     theme(legend.position = "bottom", plot.title = element_text(hjust = 0.5),
-          legend.text = element_text(size = 10)) +
+          legend.text = element_text(size = 10),
+          plot.tag = element_text(size = 9, colour = "grey"),
+          plot.tag.position = "bottomright") +
     guides(col = guide_legend(nrow = 2, byrow = T)) + 
     guides(shape = guide_legend(nrow = 2, byrow = T)) +
     scale_color_manual(values = col_palette) +
@@ -153,10 +157,11 @@ vote_plot <- function(mets, counts = NULL) {
   #' 
   #' @importFrom stats reorder
   #' @examples 
-  #' data("sample_data")
-  #' 
-  #' result <- compute_amanida(sample_data)
-  #' vote_plot(result)
+  #' \dontrun{
+  #'     data("sample_data")
+  #'     result <- compute_amanida(sample_data)
+  #'     vote_plot(result)
+  #' }
   #' 
   #' @export
   #' 
@@ -208,10 +213,13 @@ vote_plot <- function(mets, counts = NULL) {
           panel.grid.minor = element_blank(),
           panel.grid.major.y = element_blank(), 
           panel.border = element_blank(), 
-          panel.grid.major.x = element_line(linetype = "dashed")) +
+          panel.grid.major.x = element_line(linetype = "dashed"),
+          plot.tag = element_text(size = 9, colour = "grey"),
+          plot.tag.position = "bottomright") +
     coord_flip() +
     ylab("Vote-counting") +
     xlab('')+
+    labs(tag = "Created with amanida") +
     ggtitle("Total vote count of compounds behaviour") +
     scale_y_continuous(expand = c(0.6, 0), 
                        breaks = seq(min(.$votes), max(.$votes), by = 1),
@@ -367,10 +375,12 @@ explore_plot <- function(data, type = "all", counts = NULL) {
         theme_minimal() +
         xlab("Counts by trend") + 
         ylab("") +
-        labs(fill = "Counts by trend") +
+        labs(fill = "Counts by trend", tag = "Created with amanida") +
         ggtitle("Qualitative compounds trend plot") +
         theme(legend.position = "bottom", legend.title = element_blank(),
-              axis.text.y = element_text(size = 14)) +
+              axis.text.y = element_text(size = 14),
+              plot.tag = element_text(size = 9, colour = "grey"),
+              plot.tag.position = "bottomright") +
         guides(col = guide_legend(nrow = 2, byrow = T)) + 
         guides(shape = guide_legend(nrow = 2, byrow = T)) 
     }
